verify_written_files

Function verify_written_files 

fn verify_written_files(
    fs_root: &Path,
    depth: usize,
    width: usize,
    symlink_count: u32,
    symlink_mode: Option<SymlinkMode>,
) -> (usize, Vec<PathBuf>)
Verifies that all files and symlinks have the expected sentinel content. Returns (total_checked, mismatched_paths).

We use this when using --track-writes/track_writes. We can’t use the same trick that reads do, because write/write_link will never invalidate their caller (their return value is Vc<()>).